### Provider selector
Select an Oni provider using the dropdown to set the current Oni provider.

The tooltip of the selector displays the current provider address.

### Add provider
You can add an Oni provider if your data is stored somewhere running an Oni implementation that isn't listed in the dropdown.

To add a provider, click the "Add new provider" button and fill out the fields. The provider name can be anything but not cannot be left empty. The Provider address should be the base URL of the provider, e.g. https://data.ldaca.edu.au